/* Routines to print constraints on b*dN/dz for NVSS.
 * This is not a fitting routine and is used only to
 * produce data for visual display.
 */

void get_nvss_fconstraint(double **dist, COSMOPARAM *p) {
  int sample, iz, jz, ifrac, Nfrac=10;
  char FileName[1024];
  double out[3], this_out[3], Kp, Km;
  double mydist[NZ];
  double cross_win[NZ];
  double sum_cross_win, zmed;
  double poisson[] = {9.946E-07, 6.057E-07, 3.572E-07, 2.205E-07,
    3.398E-07, 1.986E-07, 0, 1.359E-07, 1.427E-07};

  /* Run over all samples, skipping 6 (NVSS) */
  for(sample=0; sample<9; sample++) {
    if (sample==6) sample++;

    /* Get file name */
    if (sample==0) sprintf(FileName, "data/nvss-2mass0.dat");
    if (sample==1) sprintf(FileName, "data/nvss-2mass1.dat");
    if (sample==2) sprintf(FileName, "data/nvss-2mass2.dat");
    if (sample==3) sprintf(FileName, "data/nvss-2mass3.dat");
    if (sample==4) sprintf(FileName, "data/nvss-lrg0.dat");
    if (sample==5) sprintf(FileName, "data/nvss-lrg1.dat");
    if (sample==7) sprintf(FileName, "data/nvss-qso0.dat");
    if (sample==8) sprintf(FileName, "data/nvss-qso1.dat");

    /* Get total constraint on f(z) */
    for(iz=0; iz<NZ; iz++)
      mydist[iz] = 1.;
    getchi2_1p(FileName, dist[sample], mydist, p, out, poisson[sample]);
    printf("%8.6lf %8.6lf ", -out[1]/out[2], sqrt(2./out[2]));

    /* Get redshift window function */
    for(iz=0; iz<NZ; iz++) {
      for(jz=0; jz<NZ; jz++)
        mydist[jz] = 1.;
      mydist[iz]=2.;
      getchi2_1p(FileName, dist[sample], mydist, p, this_out, poisson[sample]);
      Kp = this_out[2];
      mydist[iz]=0.;
      getchi2_1p(FileName, dist[sample], mydist, p, this_out, poisson[sample]);
      Km = this_out[2];
      cross_win[iz] = (Kp-Km)/(4.*out[2]);
    }

    /* Find 1/N-tiles */
    sum_cross_win = 0.;
    ifrac = 1;
    for(iz=0; iz<NZ; iz++) {
      sum_cross_win += cross_win[iz];
      while (sum_cross_win>ifrac/(double)Nfrac && ifrac<Nfrac) {
        printf("%4.2f ", iz*ZSTEP);
        if (ifrac==5) zmed=iz*ZSTEP;
        ifrac++;
      }
    }

    /* Report distance to 50% point */
    printf("%7.1lf ", DNget_r(p,0,zmed));

    /* Terminate line, indicate file */
    printf("%s\n", FileName);
  }
}
